CoinbasePro: A Python API
=========================

.. image:: https://img.shields.io/pypi/v/coinbasepro.svg
    :target: https://pypi.org/project/requests/

.. image:: https://img.shields.io/pypi/l/requests.svg
    :target: https://pypi.org/project/requests/

.. image:: https://img.shields.io/pypi/pyversions/requests.svg
    :target: https://pypi.org/project/requests/

Features
--------
- Full support of Coinbase Pro REST API
- Pythonic abstractions for a clean interface


Installation
------------

.. code-block:: bash

    $ pip install coinbasepro